Constants (:mod:`erlab.constants`)
==================================


.. automodule:: erlab.constants



   .. rubric:: Module Attributes

   .. autosummary::

      e
      c
      m_e
      mcsq
      mcsq_eV
      h
      hc
      hbar
      hbarc
      hbarsq
      h_eV
      hc_eV
      hbar_eV
      hbarsq_eV
      rel_eV_nm
      rel_kconv
      rel_kzconv
      kb
      kb_eV





   .. rubric:: Functions

   .. autosummary::

      conv_eV_nm
      conv_watt_photons
